@@ -21,7 +21,8 @@ class ListApiView(ResponseViewMixin, BaseApiViews):
     async def handler(self, request: Request, *args, **kwargs):
         self.valid_serializer_class()
         instances = await self.filter_queryset(self.get_queryset())
-        return self.success(self.serializer_class(many=True).dump(instances))
+        result = await self.serializer_class(instance=instances, many=True).data
+        return self.success(result)
 
 
 class RetrieveApiView(ResponseViewMixin, BaseApiViews):
@@ -33,7 +34,7 @@ class RetrieveApiView(ResponseViewMixin, BaseApiViews):
     async def handler(self, request: Request, *args, **kwargs):
         self.valid_serializer_class()
         instance = await self.get_object()
-        return self.success(self.serializer_class().dump(instance))
+        return self.success(await self.serializer_class(instance=instance, many=True).data)
 
 
 class CreateApiView(ResponseViewMixin, BaseApiViews):
@@ -45,7 +46,7 @@ class CreateApiView(ResponseViewMixin, BaseApiViews):
         serializers = self.serializer_class(self.data)
         instance = serializers.instance
         await instance.save()
-        return self.success(self.serializer_class(instance=instance).data)
+        return self.success(await self.serializer_class(instance=instance).data)
 
 
 class UpdateApiView(ResponseViewMixin, BaseApiViews):
@@ -64,9 +65,9 @@ class UpdateApiView(ResponseViewMixin, BaseApiViews):
         partial = self.get_partial() if is_patch else False
         serializers = self.serializer_class(data=self.data, partial=partial)
         instance = await self.get_object()
-        instance = instance.update_from_dict(serializers.valid_data)
+        instance = instance.update_from_dict(await serializers.valid_data)
         await instance.save()
-        return self.success(self.serializer_class(instance=instance).data)
+        return self.success(await self.serializer_class(instance=instance).data)
 
     def get_partial(self):
         partial = tuple(set(self.serializer_class._declared_fields.keys()).difference(set(self.data.keys())))
